@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 # Copyright (C) 2008 Novell Inc.  All rights reserved.
 # This program is free software; it may be used, copied, modified
 # and distributed under the terms of the GNU General Public Licence,
@@ -74,7 +72,7 @@ def run(prg):
         return 1
 
     except oscerr.LinkExpandError, e:
-        print >>sys.stderr, 'Link cannot be expanded:\n', e
+        print >>sys.stderr, 'Link "%s/%s" cannot be expanded:\n' % (e.prj, e.pac), e.msg
         print >>sys.stderr, 'Use "osc repairlink" to fix merge conflicts.\n'
         return 1
 
