@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 # Copyright (C) 2006 Novell Inc.  All rights reserved.
 # This program is free software; it may be used, copied, modified
 # and distributed under the terms of the GNU General Public Licence,
@@ -11,6 +9,7 @@ import os
 import re
 import sys
 from tempfile import NamedTemporaryFile
+from shutil import rmtree
 from osc.fetch import *
 from osc.core import get_buildinfo, store_read_apiurl, store_read_project, store_read_package, meta_exists, quote_plus, get_buildconfig
 import osc.conf
@@ -34,7 +33,9 @@ change_personality = {
 can_also_build = { 
              'armv4l': [                                         'armv4l'                                 ],
              'armv5el':[                                         'armv4l', 'armv5el'                      ],
+             'armv6l' :[                                         'armv4l', 'armv5el'                      ],
              'armv7el':[                                         'armv4l', 'armv5el', 'armv7el'           ],
+             'armv7l' :[                                         'armv4l', 'armv5el', 'armv7el'           ],
              's390x':  ['s390'                                                                            ],
              'ppc64':  [                        'ppc', 'ppc64',                                           ],
              'i386':   [        'i586',                          'armv4l', 'armv5el', 'armv7el',    'sh4' ],
@@ -144,7 +145,7 @@ class Pac:
         self.mp['repopackage'] = node.get('package') or '_repository'
         self.mp['repoarch'] = node.get('repoarch') or self.mp['arch']
 
-        if not (self.mp['name'] and self.mp['arch'] and self.mp['version']):
+        if pacsuffix == 'deb' and not (self.mp['name'] and self.mp['arch'] and self.mp['version']):
             raise oscerr.APIError(
                 "buildinfo for package %s/%s/%s is incomplete" 
                     % (self.mp['name'], self.mp['arch'], self.mp['version']))
@@ -207,7 +208,9 @@ def get_built_files(pacdir, pactype):
         b_built = subprocess.Popen(['find', os.path.join(pacdir, 'DEBS'),
                                     '-name', '*.deb'],
                                    stdout=subprocess.PIPE).stdout.read().strip()
-        s_built = ''
+        s_built = subprocess.Popen(['find', os.path.join(pacdir, 'SOURCES.DEB'), 
+                                    '-type', 'f'],
+                                   stdout=subprocess.PIPE).stdout.read().strip()
     return s_built, b_built
 
 
@@ -324,7 +327,10 @@ def main(opts, argv):
 
 
     print 'Getting buildinfo from server'
-    bi_file = NamedTemporaryFile(suffix='.xml', prefix='buildinfo.', dir = '/tmp')
+    tempdir = '/tmp'
+    if sys.platform[:3] == 'win':
+        tempdir = os.getenv('TEMP')
+    bi_file = NamedTemporaryFile(suffix='.xml', prefix='buildinfo.', dir = tempdir)
     try:
         bi_text = ''.join(get_buildinfo(apiurl, 
                                         prj,
@@ -413,8 +419,33 @@ def main(opts, argv):
     # now update the package cache
     fetcher.run(bi)
 
-    if build_type == 'kiwi' and not os.path.exists('repos'):
-        os.symlink(config['packagecachedir'], 'repos')
+    # Make packages from buildinfo available as repos for kiwi
+    if build_type == 'kiwi':
+        if not os.path.exists('repos'):
+            os.mkdir('repos')
+        else:
+            rmtree('repos')
+            os.mkdir('repos')
+        for i in bi.deps:
+            # project
+            pdir = str(i.extproject).replace(':/', ':')
+            # repo
+            rdir = str(i.extrepository).replace(':/', ':')
+            # arch
+            adir = i.repoarch
+            # project/repo
+            prdir = "repos/"+pdir+"/"+rdir
+            # project/repo/arch
+            pradir = prdir+"/"+adir
+            # source fullfilename
+            sffn = i.fullfilename
+            print "Using package: "+sffn
+            # target fullfilename
+            tffn = pradir+"/"+sffn.split("/")[-1]
+            if not os.path.exists(os.path.join(pradir)):
+                os.makedirs(os.path.join(pradir))
+            if not os.path.exists(tffn):
+                os.symlink(sffn, tffn)
 
     if bi.pacsuffix == 'rpm':
         """don't know how to verify .deb packages. They are verified on install
@@ -438,7 +469,10 @@ def main(opts, argv):
     rpmlist.append('vminstall: ' + ' '.join(bi.vminstall_list) + '\n')
     rpmlist.append('runscripts: ' + ' '.join(bi.runscripts_list) + '\n')
 
-    rpmlist_file = NamedTemporaryFile(prefix='rpmlist.', dir = '/tmp')
+    tempdir = '/tmp'
+    if sys.platform[:3] == 'win':
+        tempdir = os.getenv('TEMP')
+    rpmlist_file = NamedTemporaryFile(prefix='rpmlist.', dir = tempdir)
     rpmlist_file.writelines(rpmlist)
     rpmlist_file.flush()
     os.fsync(rpmlist_file)
@@ -446,7 +480,10 @@ def main(opts, argv):
 
 
     print 'Getting buildconfig from server'
-    bc_file = NamedTemporaryFile(prefix='buildconfig.', dir = '/tmp')
+    tempdir = '/tmp'
+    if sys.platform[:3] == 'win':
+        tempdir = os.getenv('TEMP')
+    bc_file = NamedTemporaryFile(prefix='buildconfig.', dir = tempdir)
     bc_file.write(get_buildconfig(apiurl, prj, pac, repo, arch))
     bc_file.flush()
 
