@@ -17,6 +17,7 @@ import mmap
 import os
 import stat
 import struct
+import sys
 
 # format implementation is based on src/copyin.c and src/util.c (see cpio sources)
 
@@ -27,7 +28,7 @@ class CpioError(Exception):
         self.file = fn
         self.msg = msg
 
-class CpioHdr():
+class CpioHdr:
     """
     Represents a cpio header ("New" portable format and CRC format).
     """
@@ -64,7 +65,7 @@ class CpioHdr():
     def __str__(self):
         return "%s %s %s %s" % (self.filename, self.filesize, self.namesize, self.dataoff)
 
-class Cpio():
+class Cpio:
     """
     Represents a cpio archive.
     Supported formats:
@@ -139,9 +140,12 @@ class Cpio():
         if not self.__file:
             self.__file = open(self.filename, 'rb')
             try:
-                self.__file = mmap.mmap(self.__file.fileno(), 0, prot = mmap.PROT_READ)
+                if sys.platform[:3] != 'win':
+                    self.__file = mmap.mmap(self.__file.fileno(), 0, prot = mmap.PROT_READ)
+                else:
+                    self.__file = mmap.mmap(self.__file.fileno(), 0)
             except EnvironmentError, e:
-                if e.errno == 19:
+                if e.errno == 19 or ( hasattr(e, 'winerror') and e.winerror == 5 ):
                     print >>sys.stderr, 'cannot use mmap to read the file, failing back to default'
                 else:
                     raise e
